USE carbondb;

DROP PROCEDURE IF EXISTS `WSO2_TOKEN_CLEANUP_DATA_RESTORE_SP`;
DELIMITER $$
CREATE PROCEDURE `WSO2_TOKEN_CLEANUP_DATA_RESTORE_SP`()

BEGIN

DECLARE rowCount INT;
DECLARE enableLog BOOLEAN;
DECLARE logLevel VARCHAR(10);

-- ------------------------------------------
-- CONFIGURABLE ATTRIBUTES
-- ------------------------------------------
SET enableLog = TRUE; -- ENABLE LOGGING [DEFAULT : TRUE]
SET logLevel := 'TRACE'; -- SET LOG LEVELS : TRACE



IF (enableLog) THEN
SELECT  'CLEANUP DATA RESTORATION STARTED .... !';
END IF;


-- ---------------------

SELECT COUNT(1) INTO rowcount  FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA IN (SELECT DATABASE())  AND TABLE_NAME IN ('IDN_OAUTH2_ACCESS_TOKEN');
IF (rowcount = 1)
THEN
IF (enableLog AND logLevel IN ('TRACE')) THEN
SELECT  'CLEANUP DATA RESTORATION STARTED ON IDN_OAUTH2_ACCESS_TOKEN TABLE !';
END IF;
INSERT INTO IDN_OAUTH2_ACCESS_TOKEN SELECT A.* FROM BAK_IDN_OAUTH2_ACCESS_TOKEN A LEFT JOIN IDN_OAUTH2_ACCESS_TOKEN B ON A.TOKEN_ID = B.TOKEN_ID WHERE B.TOKEN_ID IS NULL;
SELECT row_count() INTO rowcount;
IF (enableLog ) THEN
SELECT  'CLEANUP DATA RESTORATION COMPLETED ON IDN_OAUTH2_ACCESS_TOKEN WITH %',rowcount;
END IF;
END IF;

-- ---------------------

SELECT COUNT(1) INTO rowcount  FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA IN (SELECT DATABASE())  AND TABLE_NAME IN ('IDN_OAUTH2_AUTHORIZATION_CODE');
IF (rowcount = 1)
THEN
IF (enableLog AND logLevel IN ('TRACE')) THEN
SELECT  'CLEANUP DATA RESTORATION STARTED ON IDN_OAUTH2_AUTHORIZATION_CODE TABLE !';
END IF;
INSERT INTO IDN_OAUTH2_AUTHORIZATION_CODE SELECT A.* FROM BAK_IDN_OAUTH2_AUTHORIZATION_CODE A LEFT JOIN IDN_OAUTH2_AUTHORIZATION_CODE B ON A.CODE_ID = B.CODE_ID WHERE B.CODE_ID IS NULL;
SELECT row_count() INTO rowcount;
IF (enableLog ) THEN
SELECT  'CLEANUP DATA RESTORATION COMPLETED ON IDN_OAUTH2_AUTHORIZATION_CODE WITH %',rowcount;
END IF;
END IF;

-- ---------------------

SELECT COUNT(1) INTO rowcount  FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA IN (SELECT DATABASE()) AND TABLE_NAME IN ('IDN_OAUTH2_ACCESS_TOKEN_SCOPE');
IF (rowcount = 1)
THEN
IF (enableLog AND logLevel IN ('TRACE')) THEN
SELECT  'CLEANUP DATA RESTORATION STARTED ON IDN_OAUTH2_ACCESS_TOKEN_SCOPE TABLE !';
END IF;
INSERT INTO IDN_OAUTH2_ACCESS_TOKEN_SCOPE SELECT A.* FROM BAK_IDN_OAUTH2_ACCESS_TOKEN_SCOPE A LEFT JOIN IDN_OAUTH2_ACCESS_TOKEN_SCOPE B ON A.TOKEN_ID = B.TOKEN_ID AND A.TOKEN_SCOPE = B.TOKEN_SCOPE WHERE B.TOKEN_ID IS NULL;
SELECT row_count() INTO rowcount;
IF (enableLog ) THEN
SELECT  'CLEANUP DATA RESTORATION COMPLETED ON IDN_OAUTH2_ACCESS_TOKEN_SCOPE WITH %',rowcount;
END IF;
END IF;

-- ---------------------

SELECT COUNT(1) INTO rowcount  FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA IN (SELECT DATABASE())  AND TABLE_NAME IN ('IDN_OIDC_REQ_OBJECT_REFERENCE');
IF (rowcount = 1)
THEN
IF (enableLog AND logLevel IN ('TRACE')) THEN
SELECT  'CLEANUP DATA RESTORATION STARTED ON IDN_OIDC_REQ_OBJECT_REFERENCE TABLE !';
END IF;
INSERT INTO IDN_OIDC_REQ_OBJECT_REFERENCE SELECT A.* FROM BAK_IDN_OIDC_REQ_OBJECT_REFERENCE A LEFT JOIN IDN_OIDC_REQ_OBJECT_REFERENCE B ON A.ID = B.ID WHERE B.ID IS NULL;
SELECT row_count() INTO rowcount;
IF (enableLog ) THEN
SELECT  'CLEANUP DATA RESTORATION COMPLETED ON IDN_OIDC_REQ_OBJECT_REFERENCE WITH %',rowcount;
END IF;
END IF;

-- --------------------

SELECT COUNT(1) INTO rowcount  FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA IN (SELECT DATABASE()) AND TABLE_NAME IN ('IDN_OIDC_REQ_OBJECT_CLAIMS');
IF (rowcount = 1)
THEN
IF (enableLog AND logLevel IN ('TRACE')) THEN
SELECT  'CLEANUP DATA RESTORATION STARTED ON IDN_OIDC_REQ_OBJECT_CLAIMS TABLE !';
END IF;
INSERT INTO IDN_OIDC_REQ_OBJECT_CLAIMS SELECT A.* FROM BAK_IDN_OIDC_REQ_OBJECT_CLAIMS A LEFT JOIN IDN_OIDC_REQ_OBJECT_CLAIMS B ON A.ID = B.ID WHERE B.ID IS NULL;
SELECT row_count() INTO rowcount;
IF (enableLog ) THEN
SELECT  'CLEANUP DATA RESTORATION COMPLETED ON IDN_OIDC_REQ_OBJECT_CLAIMS WITH %',rowcount;
END IF;
END IF;

-- -------------------

SELECT COUNT(1) INTO rowcount  FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA IN (SELECT DATABASE()) AND TABLE_NAME IN ('IDN_OIDC_REQ_OBJ_CLAIM_VALUES');
IF (rowcount = 1)
THEN
IF (enableLog AND logLevel IN ('TRACE')) THEN
SELECT  'CLEANUP DATA RESTORATION STARTED ON IDN_OIDC_REQ_OBJ_CLAIM_VALUES TABLE !';
END IF;
INSERT INTO IDN_OIDC_REQ_OBJ_CLAIM_VALUES SELECT A.* FROM BAK_IDN_OIDC_REQ_OBJ_CLAIM_VALUES A LEFT JOIN IDN_OIDC_REQ_OBJ_CLAIM_VALUES B ON A.ID = B.ID WHERE B.ID IS NULL;
SELECT row_count() INTO rowcount;
IF (enableLog ) THEN
SELECT  'CLEANUP DATA RESTORATION COMPLETED ON IDN_OIDC_REQ_OBJ_CLAIM_VALUES WITH %',rowcount;
END IF;
END IF;

IF (enableLog) THEN
SELECT  'CLEANUP DATA RESTORATION COMPLETED .... !';
END IF;


END$$

DELIMITER ;
